@@ -1,20 +1,7 @@
 /*
-   Copyright (C) 2012-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2012-2020 Laurent Montel <montel@kde.org>
 
-   This program is free software; you can redistribute it and/or
-   modify it under the terms of the GNU General Public
-   License as published by the Free Software Foundation; either
-   version 2 of the License, or (at your option) any later version.
-
-   This program is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-   General Public License for more details.
-
-   You should have received a copy of the GNU General Public License
-   along with this program; see the file COPYING.  If not, write to
-   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-   Boston, MA 02110-1301, USA.
+   SPDX-License-Identifier: GPL-2.0-or-later
 */
 
 #include "importfilterinfogui.h"
@@ -71,7 +58,7 @@ void ImportFilterInfoGui::setOverall(int percent)
 
 void ImportFilterInfoGui::addInfoLogEntry(const QString &log)
 {
-    QListWidgetItem *item = new QListWidgetItem(log);
+    auto *item = new QListWidgetItem(log);
     item->setForeground(Qt::blue);
     m_parent->mailWidget()->addItem(item);
     m_parent->mailWidget()->setLastCurrentItem();
@@ -80,7 +67,7 @@ void ImportFilterInfoGui::addInfoLogEntry(const QString &log)
 
 void ImportFilterInfoGui::addErrorLogEntry(const QString &log)
 {
-    QListWidgetItem *item = new QListWidgetItem(log);
+    auto *item = new QListWidgetItem(log);
     item->setForeground(Qt::red);
     m_parent->mailWidget()->addItem(item);
     m_parent->mailWidget()->setLastCurrentItem();
